@@ -17,11 +17,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 
 
 def check_args(args):
     len_args = len(args.script) - 1
-    if len_args is not 1:
+    if len_args != 1:
         message = """
         This script will display all hosts with the searched applications!
 
@@ -43,22 +45,22 @@ def print_assets(gmp, appname):
     for host in hosts:
         ip = host.xpath('ip/text()')
         hostname = host.xpath('detail/name[text()="hostname"]/../value/text()')
-        if len(hostname) is 0:
+        if len(hostname) == 0:
             hostname = ""
         else:
             hostname = hostname[0]
 
-        print('{ip} ({hostname})'.format(ip=ip, hostname=hostname))
+        print(f'{ip} ({hostname})')
         apps = host.xpath(
             'detail/name[text() = "App"]/../value['
-            'contains(text(), "{0}")]/text()'.format(appname)
+            f'contains(text(), "{appname}")]/text()'
         )
         for app in apps:
             print('\t' + app)
         print('\n')
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
