@@ -17,13 +17,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
-
+from argparse import Namespace
 from gvm.errors import GvmError
+from gvm.protocols.gmp import Gmp
 
 
 def check_args(args):
     len_args = len(args.script) - 1
-    if len_args is not 1:
+    if len_args != 1:
         message = """
         This script creates a new scan config with nvts from a given CERT-Bund!
         It needs one parameter after the script name.
@@ -38,7 +39,7 @@ def check_args(args):
         sys.exit()
 
 
-def create_config(gmp, cert_bund_name):
+def create_scan_config(gmp, cert_bund_name):
     cert_bund_details = gmp.get_info(
         info_id=cert_bund_name, info_type=gmp.types.InfoType.CERT_BUND_ADV
     )
@@ -60,7 +61,7 @@ def create_config(gmp, cert_bund_name):
             oid = nvt.xpath('@oid')[0]
 
             # We need the nvt family to modify scan config
-            nvt_data = gmp.get_nvt(oid)
+            nvt_data = gmp.get_scan_config_nvt(oid)
             family = nvt_data.xpath('nvt/family/text()')[0]
 
             # Create key value map
@@ -71,36 +72,40 @@ def create_config(gmp, cert_bund_name):
 
     # Create new config
     copy_id = '085569ce-73ed-11df-83c3-002264764cea'
-    config_name = 'scanconfig_for_%s' % cert_bund_name
+    config_name = f'scanconfig_for_{cert_bund_name}'
     config_id = ''
 
     try:
-        res = gmp.create_config(copy_id, config_name)
+        res = gmp.create_scan_config(copy_id, config_name)
         config_id = res.xpath('@id')[0]
 
         # Modify the config with the nvts oid
         for family, nvt_oid in nvt_dict.items():
-            gmp.modify_config(config_id, nvt_oids=nvt_oid, family=family)
+            gmp.modify_scan_config(
+                config_id=config_id, nvt_oids=nvt_oid, family=family
+            )
 
         # This nvts must be present to work
         family = 'Port scanners'
         nvts = ['1.3.6.1.4.1.25623.1.0.14259', '1.3.6.1.4.1.25623.1.0.100315']
-        gmp.modify_config(config_id=config_id, nvt_oids=nvts, family=family)
+        gmp.modify_scan_config(
+            config_id=config_id, nvt_oids=nvts, family=family
+        )
 
     except GvmError:
         print('Config exist')
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
 
     cert_bund_name = args.script[1]
 
-    print('Creating scan config for {0}'.format(cert_bund_name))
+    print(f'Creating scan config for {cert_bund_name}')
 
-    create_config(gmp, cert_bund_name)
+    create_scan_config(gmp, cert_bund_name)
 
 
 if __name__ == '__gmp__':
