@@ -18,12 +18,14 @@
 
 import time
 import sys
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 
 
 def check_args(args):
     len_args = len(args.script) - 1
 
-    if len_args is not 1:
+    if len_args != 1:
         message = """
         This script deletes overrides with a specific filter value
 
@@ -41,10 +43,10 @@ def delete_overrides(gmp, filter_value):
     filters = gmp.get_overrides(filter=filter_value)
 
     if not filters.xpath('override'):
-        print('No overrides with filter: %s' % filter_value)
+        print(f'No overrides with filter: {filter_value}')
 
     for f_id in filters.xpath('override/@id'):
-        print('Delete override: %s' % f_id, end='')
+        print(f'Delete override: {f_id}', end='')
         res = gmp.delete_override(f_id)
 
         if 'OK' in res.xpath('@status_text')[0]:
@@ -55,7 +57,7 @@ def delete_overrides(gmp, filter_value):
         time.sleep(60)
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
