@@ -18,7 +18,8 @@
 
 import sys
 from datetime import datetime
-
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 from gvm.errors import GvmError
 
 
@@ -40,68 +41,71 @@ def check_args(args):
         sys.exit()
 
 
-def create_config(gmp, nvt_oid):
+def create_scan_config(gmp, nvt_oid) -> str:
     # Create new config
     copy_id = '085569ce-73ed-11df-83c3-002264764cea'
     config_name = nvt_oid
     config_id = ''
 
     try:
-        res = gmp.create_config(copy_id, config_name)
+        res = gmp.create_scan_config(copy_id, config_name)
         config_id = res.xpath('@id')[0]
 
         # Modify the config with an nvt oid
-        nvt = gmp.get_nvt(nvt_oid)
+        nvt = gmp.get_scan_config_nvt(nvt_oid)
         family = nvt.xpath('nvt/family/text()')[0]
 
-        gmp.modify_config(
-            config_id, 'nvt_selection', nvt_oids=[nvt_oid], family=family
+        gmp.modify_scan_config_set_nvt_selection(
+            config_id=config_id, nvt_oids=[nvt_oid], family=family
         )
 
         # This nvts must be present to work
         family = 'Port scanners'
         nvts = ['1.3.6.1.4.1.25623.1.0.14259', '1.3.6.1.4.1.25623.1.0.100315']
-        gmp.modify_config(
-            config_id, 'nvt_selection', nvt_oids=nvts, family=family
+        gmp.modify_scan_config_set_nvt_selection(
+            config_id, nvt_oids=nvts, family=family
         )
 
     except GvmError:
-        res = gmp.get_configs(filter='name=%s' % config_name)
+        res = gmp.get_scan_configs(filter_string=f'name={config_name}')
         config_id = res.xpath('config/@id')[0]
 
     return config_id
 
 
-def create_target(gmp, name):
+def create_target(gmp: Gmp, name: str) -> str:
     try:
         res = gmp.create_target(name, hosts=[name])
         target_id = res.xpath('@id')[0]
     except GvmError:
-        res = gmp.get_targets(filter='name=%s hosts=%s' % (name, name))
+        res = gmp.get_targets(filter_string=f'name={name} hosts={name}')
         target_id = res.xpath('target/@id')[0]
 
     return target_id
 
 
-def create_and_start_task(gmp, name, nvt_oid, config_id, target_id):
+def create_and_start_task(
+    gmp: Gmp, name: str, nvt_oid: str, config_id: str, target_id: str
+) -> None:
     # Standard Scanner OpenVAS Default
     scanner_id = '08b69003-5fc2-4037-a479-93b440211c73'
-
+    date_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
     # Create task
-    task_name = '%s_%s_%s' % (
-        name,
-        nvt_oid,
-        datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
+    task_name = f'{name}_{nvt_oid}_{date_time}'
+    res = gmp.create_task(
+        name=task_name,
+        config_id=config_id,
+        target_id=target_id,
+        scanner_id=scanner_id,
     )
-    res = gmp.create_task(task_name, config_id, target_id, scanner_id)
     task_id = res.xpath('@id')[0]
 
     # Start the task
-    gmp.start_task(task_id)
-    print('\nTask %s started' % task_id)
+    gmp.start_task(task_id=task_id)
+    print(f'\nTask {task_id} started')
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
@@ -109,7 +113,7 @@ def main(gmp, args):
     nvt_oid = args.script[1]
     target_name = args.script[2]
 
-    config_id = create_config(gmp, nvt_oid)
+    config_id = create_scan_config(gmp, nvt_oid)
     target_id = create_target(gmp, target_name)
 
     create_and_start_task(gmp, target_name, nvt_oid, config_id, target_id)
