@@ -17,11 +17,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
-from gvm.protocols.gmpv9.types import get_alive_test_from_string
+from argparse import Namespace
+from lxml.etree import Element
+from gvm.protocols.gmp import Gmp
 from gvmtools.helper import create_xml_tree, yes_or_no
 
 
-def check_args(args):
+def check_args(args: Namespace) -> None:
     len_args = len(args.script) - 1
     if len_args != 1:
         message = """
@@ -39,7 +41,7 @@ def check_args(args):
         sys.exit()
 
 
-def parse_send_xml_tree(gmp, xml_tree):
+def parse_send_xml_tree(gmp: Gmp, xml_tree: Element) -> None:
     credential_options = [
         'ssh_credential',
         'smb_credential',
@@ -71,10 +73,8 @@ def parse_send_xml_tree(gmp, xml_tree):
                 continue
             if cred_id not in credentials:
                 response = yes_or_no(
-                    "\nThe credential '{}' for 'target {}' could not be "
-                    "located...\nWould you like to continue?".format(
-                        credential, counter
-                    )
+                    f"\nThe credential '{credential}' for 'target {counter}' "
+                    "could not be located...\nWould you like to continue?"
                 )
 
                 if response is False:
@@ -83,15 +83,17 @@ def parse_send_xml_tree(gmp, xml_tree):
                 else:
                     continue
 
-            key = '{}_id'.format(credential)
+            key = f'{credential}_id'
             keywords[key] = cred_id
             elem_path = target.find(credential)
             port = elem_path.find('port')
             if port is not None and port.text is not None:
-                port_key = '{}_port'.format(credential)
+                port_key = f'{credential}_port'
                 keywords[port_key] = elem_path.find('port').text
 
-        alive_test = get_alive_test_from_string(target.find('alive_tests').text)
+        alive_test = gmp.types.AliveTest.from_string(
+            target.find('alive_tests').text
+        )
 
         if alive_test is not None:
             keywords['alive_test'] = alive_test
@@ -120,7 +122,7 @@ def parse_send_xml_tree(gmp, xml_tree):
         counter += 1
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
