@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2018 inovex GmbH
+# Copyright (C) 2019-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,6 +18,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
+from typing import List
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 
 
 def check_args(args):
@@ -38,7 +42,7 @@ ssh --hostname <gsm> scripts/start-multiple-alert-scan.gmp.py <sender_email> <re
 
 
 # returns a list containing all port_list names
-def get_port_list_names(gmp):
+def get_port_list_names(gmp) -> List[str]:
     res = gmp.get_port_lists()
     port_names_list = [""]
     for name in res.findall("port_list/name"):
@@ -46,9 +50,9 @@ def get_port_list_names(gmp):
     return port_names_list
 
 
-def get_config(gmp, debug=False):
+def get_scan_config(gmp, debug=False):
     # get all configs of the openvas instance
-    res = gmp.get_configs()
+    res = gmp.get_scan_configs()
 
     # configurable template
     template = "fast"
@@ -77,13 +81,13 @@ def get_config(gmp, debug=False):
         if template_abbreviation_mapper.get(template, "-") == name:
             config_id = cid
             if debug:
-                print("%s: %s" % (name, config_id))
+                print(f"{name}: {config_id}")
             break
     # check for existence of the desired config
     if config_id == "-":
         print(
-            "error: could not recognize template '%s'\n"
-            "valid template names are: %s\n" % (template, config_list)
+            f"error: could not recognize template '{template}'\n"
+            f"valid template names are: {config_list}\n"
         )
         exit()
 
@@ -100,7 +104,7 @@ def get_target(gmp, debug=False):
     # iterate over existing targets and find a vacant targetName
     while exists:
         exists = False
-        target_name = "targetName%s" % str(counter)
+        target_name = f"targetName{str(counter)}"
         for target in targets.xpath('target'):
             name = target.xpath('name/text()')[0]
             if name == target_name:
@@ -109,14 +113,14 @@ def get_target(gmp, debug=False):
         counter += 1
 
     if debug:
-        print("target name: %s" % target_name)
+        print(f"target name: {target_name}")
 
     # iterate over existing port lists and find a vacant name
     new_port_list_name = "portlistName"
     counter = 0
 
     while True:
-        portlist_name = '%s%s' % (new_port_list_name, str(counter))
+        portlist_name = f'{new_port_list_name}{str(counter)}'
         if portlist_name not in get_port_list_names(gmp):
             break
         counter += 1
@@ -127,23 +131,25 @@ def get_target(gmp, debug=False):
     portlist = gmp.create_port_list(portlist_name, port_string)
     portlist_id = portlist.xpath('@id')[0]
     if debug:
-        print("Portlist-name:\t%s" % str(portlist_name))
-        print("Portlist-id:\t%s" % str(portlist_id))
+        print(f"Portlist-name:\t{str(portlist_name)}")
+        print(f"Portlist-id:\t{str(portlist_id)}")
 
     # configurable hosts
     hosts = ["localhost"]
 
     # integrate port list id into create_target
-    res = gmp.create_target(target_name, hosts=hosts, port_list_id=portlist_id)
+    res = gmp.create_target(
+        name=target_name, hosts=hosts, port_list_id=portlist_id
+    )
     return res.xpath('@id')[0]
 
 
-def get_alerts(gmp, sender_email, recipient_email, debug=False):
+def get_alerts(gmp, sender_email, recipient_email, debug=False) -> List[str]:
     # configurable alert name
     alert_name = recipient_email
 
     # create alert if necessary
-    alert_object = gmp.get_alerts(filter='name=%s' % alert_name)
+    alert_object = gmp.get_alerts(filter=f'name={alert_name}')
     alert_id = None
     alert = alert_object.xpath('alert')
     if len(alert) == 0:
@@ -176,19 +182,19 @@ should not have received it.
                 recipient_email: "to_address",
             },
         )
-        alert_object = gmp.get_alerts(filter='name=%s' % recipient_email)
+        alert_object = gmp.get_alerts(filter=f'name={recipient_email}')
         alert = alert_object.xpath('alert')
         alert_id = alert[0].get('id', 'no id found')
     else:
         alert_id = alert[0].get('id', 'no id found')
         if debug:
-            print("alert_id: %s" % str(alert_id))
+            print(f"alert_id: {str(alert_id)}")
 
     # second configurable alert name
-    alert_name2 = "%s-2" % recipient_email
+    alert_name2 = f"{recipient_email}-2"
 
     # create second alert if necessary
-    alert_object2 = gmp.get_alerts(filter='name=%s' % alert_name2)
+    alert_object2 = gmp.get_alerts(filter=f'name={alert_name2}')
     alert_id2 = None
     alert2 = alert_object2.xpath('alert')
     if len(alert2) == 0:
@@ -220,15 +226,15 @@ should not have received it.
                 recipient_email: "to_address",
             },
         )
-        alert_object2 = gmp.get_alerts(filter='name=%s' % recipient_email)
+        alert_object2 = gmp.get_alerts(filter=f'name={recipient_email}')
         alert2 = alert_object2.xpath('alert')
         alert_id2 = alert2[0].get('id', 'no id found')
     else:
         alert_id2 = alert2[0].get('id', 'no id found')
         if debug:
-            print("alert_id2: %s" % str(alert_id2))
+            print(f"alert_id2: {str(alert_id2)}")
 
-    return (alert_id, alert_id2)
+    return [alert_id, alert_id2]
 
 
 def get_scanner(gmp):
@@ -242,13 +248,13 @@ def create_and_start_task(
 ):
     # Create the task
     tasks = gmp.get_tasks(filter="name~ScanDoneMultipleAlert")
-    task_name = "ScanDoneMultipleAlert{0}".format(len(tasks.xpath('tasks/@id')))
+    task_name = f"ScanDoneMultipleAlert{len(tasks.xpath('tasks/@id'))}"
     task_comment = "test comment"
     res = gmp.create_task(
-        task_name,
-        config_id,
-        target_id,
-        scanner_id,
+        name=task_name,
+        config_id=config_id,
+        target_id=target_id,
+        scanner_id=scanner_id,
         alert_ids=alerts,
         comment=task_comment,
     )
@@ -256,7 +262,7 @@ def create_and_start_task(
     task_id = res.xpath('@id')[0]
     gmp.start_task(task_id)
 
-    print('Task started: %s' % task_name)
+    print(f'Task started: {task_name}')
 
     if debug:
         # Stop the task (for performance reasons)
@@ -264,7 +270,7 @@ def create_and_start_task(
         print('Task stopped')
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
@@ -272,7 +278,7 @@ def main(gmp, args):
     sender_email = args.script[1]
     recipient_email = args.script[2]
 
-    config_id = get_config(gmp)
+    config_id = get_scan_config(gmp)
     target_id = get_target(gmp)
     alerts = get_alerts(gmp, sender_email, recipient_email)
     scanner_id = get_scanner(gmp)
