@@ -17,6 +17,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 
 
 def check_args(args):
@@ -37,48 +39,43 @@ ssh --hostname <gsm> scripts/start-nvt-scan.gmp.py \
         sys.exit()
 
 
-def get_config(gmp, nvt_oid):
+def get_scan_config(gmp, nvt_oid):
     # Choose from existing config, which to copy or create new config
-    res = gmp.get_configs()
+    res = gmp.get_scan_configs()
 
     config_ids = res.xpath('config/@id')
 
     for i, conf in enumerate(res.xpath('config')):
         config_id = conf.xpath('@id')[0]
         name = conf.xpath('name/text()')[0]
-        print('\n({0}) {1}: ({2})'.format(i, name, config_id))
+        print(f'\n({i}) {name}: ({config_id})')
 
     while True:
         chosen_config = input(
-            '\nChoose your config or create new one[0-{len} | n]: '.format(
-                len=len(config_ids) - 1
-            )
+            '\nChoose your config or create new one'
+            f'[0-{len(config_ids) - 1} | n]: '
         )
 
         if chosen_config == 'n':
             chosen_copy_config = int(
-                input(
-                    'Which config to copy? [0-{len}]: '.format(
-                        len=len(config_ids) - 1
-                    )
-                )
+                input(f'Which config to copy from? [0-{len(config_ids) - 1}]: ')
             )
             config_name = input('Enter new Name for config: ')
 
             copy_id = config_ids[chosen_copy_config]
 
-            res = gmp.clone_config(copy_id)
+            res = gmp.clone_scan_config(copy_id)
 
             config_id = res.xpath('@id')[0]
 
             # Modify the config with an nvt oid
-            if len(nvt_oid) is 0:
+            if len(nvt_oid) == 0:
                 nvt_oid = input('NVT OID: ')
 
-            nvt = gmp.get_nvt(nvt_oid=nvt_oid)
+            nvt = gmp.get_scan_config_nvt(nvt_oid=nvt_oid)
             family = nvt.xpath('nvt/family/text()')[0]
 
-            gmp.modify_config(
+            gmp.modify_scan_config(
                 config_id,
                 'nvt_selection',
                 name=config_name,
@@ -93,7 +90,7 @@ def get_config(gmp, nvt_oid):
                 '1.3.6.1.4.1.25623.1.0.100315',
             ]
 
-            gmp.modify_config(
+            gmp.modify_scan_config(
                 config_id, 'nvt_selection', nvt_oids=nvts, family=family
             )
             return config_id
@@ -109,20 +106,19 @@ def get_target(gmp, hosts):
 
     for i, target in enumerate(targets.xpath('target')):
         name = target.xpath('name/text()')[0]
-        print('\n({0}) {1}'.format(i, name))
+        print(f'\n({i}) {name}')
 
     while True:
         if target_ids:
             chosen_target = input(
-                '\nChoose your target or create new one[0-{len} | n]: '.format(
-                    len=len(target_ids) - 1
-                )
+                '\nChoose your target or create new'
+                f' one[0-{len(target_ids) - 1} | n]: '
             )
         else:
             chosen_target = 'n'
 
         if chosen_target == 'n':
-            if len(hosts) is 0:
+            if len(hosts) == 0:
                 hosts = input('Target hosts (comma separated): ')
 
             name = input('Name of target: ')
@@ -142,15 +138,11 @@ def get_scanner(gmp):
         scanner_id = scanner.xpath('@id')[0]
         name = scanner.xpath('name/text()')[0]
         # configs[id] = name
-        print("\n({0})\n{1}: ({2})".format(i, name, scanner_id))
+        print(f"\n({i})\n{name}: ({scanner_id})")
 
     while True:
         chosen_scanner = int(
-            input(
-                '\nChoose your scanner [0-{len}]: '.format(
-                    len=len(scanner_ids) - 1
-                )
-            )
+            input(f'\nChoose your scanner [0-{len(scanner_ids) - 1}]: ')
         )
         if 0 <= chosen_scanner < len(scanner_ids):
             return scanner_ids[chosen_scanner]
@@ -160,7 +152,11 @@ def create_and_start_task(
     gmp, task_name, task_comment, config_id, target_id, scanner_id
 ):
     res = gmp.create_task(
-        task_name, config_id, target_id, scanner_id, comment=task_comment
+        name=task_name,
+        config_id=config_id,
+        target_id=target_id,
+        scanner_id=scanner_id,
+        comment=task_comment,
     )
 
     # Start the task
@@ -169,7 +165,7 @@ def create_and_start_task(
     print('Task started')
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
@@ -180,7 +176,7 @@ def main(gmp, args):
     task_name = input('Task name: ')
     task_comment = input('Task comment: ')
 
-    config_id = get_config(gmp, nvt_oid)
+    config_id = get_scan_config(gmp, nvt_oid)
     target_id = get_target(gmp, hosts)
     scanner_id = get_scanner(gmp)
 
